// File           : Form1.cs 
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2006
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Collections;
using Environment;
using System.Globalization;
using System.IO;

namespace ASPNETControlLocalizer
{
    /// <summary>
    /// Form1 is the main form of the ASP.NET Control Localizer
    /// </summary>
    public partial class Form1 : Form
    {
        /// <summary>
        /// Constructs a Form1 object
        /// </summary>
        public Form1()
        {
            InitializeComponent();

            int[] languagePacks = FrameworkHelper.GetLanguagePacksInstalled();
            foreach (int languagePack in languagePacks)
            {
                CultureInfo cultureInfo = new CultureInfo(languagePack);
                checkedListBoxLanguagePacks.Items.Add(cultureInfo);
            }
            if (languagePacks.GetLength(0) == 0)
                MessageBox.Show("There are no .NET Framework Language Packs installed on this machine.\n\nLocalization is not possible using this utility.", "ASP.NET Control Localizer");
        }

        private void buttonLocalize_Click(object sender, EventArgs e)
        {
            if (checkedListBoxLanguagePacks.CheckedItems.Count == 0)
                MessageBox.Show("Select at least one .NET Framework Language Pack to use for localization", "ASP.NET Control Localizer");
            else if (checkedListBoxASPXFiles.CheckedItems.Count == 0)
                MessageBox.Show("Select at least one ASPX file to localize", "ASP.NET Control Localizer");
            else
            {
                Localize();
            }
        }
        private void Localize()
        {
            ClearProgress();
            foreach (CultureInfo languagePack in checkedListBoxLanguagePacks.CheckedItems)
            {
                Progress("Localizing " + languagePack.Parent.DisplayName + "...");
                // cultureName will be something like "fr" or "es"
                string cultureName = languagePack.Parent.Name;
                foreach (string aspxFilename in checkedListBoxASPXFiles.CheckedItems)
                {
                    // if aspxFilename is "C:\Website1\Default.aspx" and cultureName is "fr" then
                    // resxFilename will be "C:\Website1\App_LocalResources\Default.aspx.fr.resx"
                    string resxFilename = Path.Combine(Path.GetDirectoryName(aspxFilename), "App_LocalResources") + @"\" +
                        Path.GetFileName(aspxFilename) + "." + cultureName + ".resx";
                    Progress("Localizing " + Path.GetFileName(aspxFilename) + "...");
                    ControlLocalizer.UpdateResources(aspxFilename, resxFilename, cultureName);
                }
            }
            Progress("Done.");
        }
        private void ClearProgress()
        {
            textBoxProgress.Text = String.Empty;
        }
        private void Progress(string text)
        {
            textBoxProgress.Text += text + System.Environment.NewLine;
        }
        private void checkedListBoxLanguagePacks_Format(object sender, ListControlConvertEventArgs e)
        {
            string displayName;
            CultureInfo cultureInfo = (CultureInfo)e.ListItem;
            if (cultureInfo.IsNeutralCulture)
                displayName = cultureInfo.DisplayName;
            else
                displayName = cultureInfo.Parent.DisplayName;

            e.Value = displayName;
        }

        private void buttonGetFiles_Click(object sender, EventArgs e)
        {
            if (textBoxASPXFolder.Text == String.Empty)
                MessageBox.Show("Enter a folder containing ASPX files", "ASP.NET Control Localizer");

            if (!Directory.Exists(textBoxASPXFolder.Text))
                MessageBox.Show("Folder does not exist", "ASP.NET Control Localizer");

            checkedListBoxASPXFiles.Items.Clear();
            string[] aspxFilenames = Directory.GetFiles(textBoxASPXFolder.Text, "*.aspx");
            foreach(string aspxFilename in aspxFilenames)
            {
                checkedListBoxASPXFiles.Items.Add(aspxFilename);
            }
        }

        private void buttonSelectAll_Click(object sender, EventArgs e)
        {
            for (int itemNumber = 0; itemNumber < checkedListBoxASPXFiles.Items.Count; itemNumber++)
            {
                checkedListBoxASPXFiles.SetItemChecked(itemNumber, true);
            }
        }

        private void buttonUnselectAll_Click(object sender, EventArgs e)
        {
            for (int itemNumber = 0; itemNumber < checkedListBoxASPXFiles.Items.Count; itemNumber++)
            {
                checkedListBoxASPXFiles.SetItemChecked(itemNumber, false);
            }
        }

        private void buttonASPXFolder_Click(object sender, EventArgs e)
        {
            folderBrowserDialog1.SelectedPath = textBoxASPXFolder.Text;
            if (folderBrowserDialog1.ShowDialog() == DialogResult.OK)
                textBoxASPXFolder.Text = folderBrowserDialog1.SelectedPath;
        }
    }
}