// File           : Default.aspx.cs 
// Original Author: Guy Smith-Ferrier
// Date Created   : July 2007
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Reflection;
using System.Net;
using System.IO;
using System.Security.Cryptography;

namespace ScriptResourceViewer
{
    public partial class _Default : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {

        }

        protected void ButtonDecrypt_Click(object sender, EventArgs e)
        {
            ShowDecrypteddParameter(DecryptString(GetdParameter(TextBox1.Text)));
            ShowDecryptedtParameter(GettParameter(TextBox1.Text));
        }
        private void ShowDecryptedtParameter(string tParameter)
        {
            LabeltParameter.Text = tParameter;
            DateTime dateTime = new DateTime((long) Convert.ToDouble(tParameter));
            LabelDateTime.Text = dateTime.ToString();
        }
        private string GettParameter(string text)
        {
            int indext = text.IndexOf("&amp;t=");
            if (indext > -1)
            {
                text = text.Substring(indext + 7);
                int indexQuote = text.IndexOf(@"""");
                if (indexQuote > -1)
                    return text.Substring(0, indexQuote);
                else
                    return text;
            }
            else
                return String.Empty;
        }
        private string GetdParameter(string text)
        {
            int indexd = text.IndexOf("?d=");
            if (indexd > -1)
            {
                int indext = text.IndexOf("&amp;t=");
                if (indext > -1)
                    return text.Substring(indexd + 3, indext - indexd - 3);
                else
                    return text.Substring(indexd + 3);
            }
            return text;
        }
        private void ShowDecrypteddParameter(string dParameter)
        {
            LabeldParameter.Text = dParameter;
            string[] bits = dParameter.Split('|');
            Labelzip.Text = bits[0].Substring(0, 1);
            if (bits[0].Substring(0, 1) == "s")
            {
                LabelAssemblyName.Text = "&nbsp;";
                LabelResourceName.Text = bits[1];
                LabelCulture.Text = "&nbsp;";
            }
            else
            {
                LabelAssemblyName.Text = bits[0].Substring(1);
                LabelResourceName.Text = bits[1];
                if (String.IsNullOrEmpty(bits[2]))
                    LabelCulture.Text = "&nbsp;";
                else
                    LabelCulture.Text = bits[2];
            }
        }
        public static string DecryptString(string queryStringParameter)
        {
            try
            {
                MethodInfo methodInfo = typeof(Page).GetMethod("DecryptString", BindingFlags.NonPublic | BindingFlags.Static);
                return (string)methodInfo.Invoke(null, new object[] { queryStringParameter });
            }
            catch (TargetInvocationException exception)
            {
                if (exception.InnerException != null && exception.InnerException is CryptographicException)
                    throw new ApplicationException("Failed to decrypt string. Check that the WebResource or ScriptResource is valid. Try generating a fresh WebResource or ScriptResource.");
                else
                    throw;
            }
        }
        public static string EncryptString(string queryStringParameter)
        {
            MethodInfo methodInfo = typeof(Page).GetMethod("EncryptString", BindingFlags.NonPublic | BindingFlags.Static);
            return (string) methodInfo.Invoke(null, new object[] { queryStringParameter });
        }

        protected void ButtonShowResource_Click(object sender, EventArgs e)
        {
            TextBoxResourceUri.Text = GetUnzippedUri(TextBoxServerUri.Text, TextBox1.Text, false);
            TextBoxResourceUriEncrypted.Text = GetUnzippedUri(TextBoxServerUri.Text, TextBox1.Text, true);
        }
        protected string GetUnzippedUri(string serverUri, string scriptResourceElement, bool encrypted)
        {
            string dParameter = DecryptString(GetdParameter(scriptResourceElement));
            string tParameter = GettParameter(scriptResourceElement);
            if (dParameter[0] == 'z' || dParameter[0] == 'Z')
                // The d parameter starts with a character to indicate that the result should be zipped.
                // Change the character to indicate that the result should not be zipped.
                dParameter = "u" + dParameter.Substring(1);

            if (encrypted)
                dParameter = EncryptString(dParameter);

            if (serverUri.EndsWith(@"/"))
                // strip the trailing slash
                serverUri = serverUri.Substring(0, serverUri.Length - 1);

            return serverUri + "/" + GetResourceType(scriptResourceElement) + ".axd?d=" + dParameter + "&t=" + tParameter;
        }
        protected string GetResourceType(string scriptResourceElement)
        {
            int index = scriptResourceElement.IndexOf(".axd");
            if (index > -1)
            {
                scriptResourceElement = scriptResourceElement.Substring(0, index);
                int indexSlash = scriptResourceElement.LastIndexOf("/");
                if (indexSlash > -1)
                    return scriptResourceElement.Substring(indexSlash + 1);
            }
            return "ScriptResource";
        }
        protected void Button1_Click(object sender, EventArgs e)
        {
            WebRequest request = WebRequest.Create(GetUnzippedUri(TextBoxServerUri.Text, TextBox1.Text, true));
            using (HttpWebResponse response = (HttpWebResponse)request.GetResponse())
            {
                using (Stream stream = response.GetResponseStream())
                {
                    using (StreamReader reader = new StreamReader(stream))
                    {
                        string responseFromServer = reader.ReadToEnd();
                        TextBoxViewResource.Text = responseFromServer;
                    }
                }
            }
        }
    }
}
