// File           : ExceptionEx.cs 
// Original Author: Guy Smith-Ferrier
// Date Created   : March 2008
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Globalization;
using System.Threading;

namespace Exceptions
{
    /// <summary>
    /// ExceptionEx contains methods that extend the Exception class
    /// </summary>
    public class ExceptionEx
    {
        /// <summary>
        /// FallbackException returns a new (unpopulated) Exception for the fallback culture
        /// </summary>
        /// <param name="exception">The exception for which a fallback exception should be created</param>
        /// <returns>The (unpopulated) Exception for the fallback culture</returns>
        /// <remarks>In this context "fallback" refers to the .NET Framework and not the application.
        /// The fallback culture for the .NET Framework is "en-US". Thus this method allows application
        /// code to get at the English exception message regardess of the culture used to construct an
        /// exception. The English exception message could be suitable for logging in a persistent store.</remarks>
        public static Exception FallbackException(Exception exception)
        {
            CultureInfo oldCurrentUICulture = Thread.CurrentThread.CurrentUICulture;
            Thread.CurrentThread.CurrentUICulture = new CultureInfo("en-US");
            Exception localizedException = (Exception)Activator.CreateInstance(exception.GetType());
            Thread.CurrentThread.CurrentUICulture = oldCurrentUICulture;
            return localizedException;
        }
    }
}
