// File           : CustomResourceSet.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Resources;
using System.Reflection;
using System.Collections;

namespace Internationalization.Resources
{
	/// <summary>
	/// CustomResourceSet is a base class ResourceSet used by custom ResourceManagers
	/// </summary>
	public class CustomResourceSet: ResourceSet
	{
        /// <summary>
        /// Constructs a CustomResourceSet object
        /// </summary>
        /// <param name="resourceReader">The IResourceReader from which the resources should be read</param>
		public CustomResourceSet(IResourceReader resourceReader): base(resourceReader)
		{
		}
        /// <summary>
        /// CreateDefaultReader creates an IResourceReader to read the resources
        /// </summary>
        /// <returns>An IResourceReader to read the resources</returns>
		public virtual IResourceReader CreateDefaultReader()
		{
			Type resourceReaderType = GetDefaultReader();
			return (IResourceReader) Activator.CreateInstance(resourceReaderType);
		}
        /// <summary>
        /// CreateDefaultWriter creates an IResourceWriter to write the resources
        /// </summary>
        /// <returns>An IResourceWriter to write the resources</returns>
		public virtual IResourceWriter CreateDefaultWriter()
		{
			Type resourceWriterType = GetDefaultWriter();
			return (IResourceWriter) Activator.CreateInstance(resourceWriterType);
		}
        /// <summary>
        /// Add adds an entry to the resources
        /// </summary>
        /// <param name="key">The key of the new resource entry</param>
        /// <param name="value">The value of the new resource entry</param>
		public virtual void Add(string key, object value)
		{
			Table.Add(key, value);
		}
        /// <summary>
        /// Table is a Hashtable of the resource entries
        /// </summary>
		public new Hashtable Table
		{
			get {return base.Table;}
		}
	}
}
