﻿// File           : Program.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.IO;
using Resources.Tools;

namespace Tools.ResClassGen
{
    /// <summary>
    /// ResClassGen is a partial replacement for the .NET Framework 2.0's ResGen utility
    /// </summary>
    /// <remarks>ResClassGen differs from ResGen in that ResClassGen:-
    /// (1) only generates strongly-typed classes
    /// (2) generates code which uses ResourceManagerProvider.GetResourceManager to creates new resource managers
    /// (instead of a hard coded reference to ResourceManager)</remarks>
	class Program
	{
		static void Main(string[] args)
		{
			if (args.GetLength(0) < 1 || !File.Exists(args[0]))
				ShowSyntax();
			else
			{
				string nameSpace = null;
				string className = null;
				string classFilename = null;
				if (args.GetLength(0) > 1)
				{
					nameSpace = args[1];
					if (args.GetLength(0) > 2)
					{
						className = args[2];
						if (args.GetLength(0) > 3)
							classFilename = args[3];
					}
				}
				StronglyTypedResourceBuilderHelper.GenerateClass(args[0], nameSpace, className, classFilename);
			}
		}
		private static void ShowSyntax()
		{
			Console.WriteLine(ProgramResources.Syntax1);
            Console.WriteLine(ProgramResources.Syntax2);
            Console.WriteLine(ProgramResources.Syntax3);
            Console.WriteLine(ProgramResources.Syntax4);
            Console.WriteLine(ProgramResources.Syntax5);
		}
	}
}
