// File           : BaseResourceCodeGenerator.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : June 2008
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using Microsoft.VisualStudio;
using Microsoft.VisualStudio.Shell.Interop;
using System;
using System.IO;
using System.Runtime.InteropServices;

namespace Microsoft.VisualStudio.Design.Serialization
{
    public abstract class BaseCodeGenerator : IVsSingleFileGenerator
    {
        private string codeFileNameSpace = string.Empty;
        private string codeFilePath = string.Empty;
        private IVsGeneratorProgress codeGeneratorProgress;

        protected BaseCodeGenerator()
        {
        }

        public abstract int DefaultExtension(out string ext);
        public int Generate(string wszInputFilePath, string bstrInputFileContents, string wszDefaultNamespace, IntPtr[] pbstrOutputFileContents, out uint pbstrOutputFileContentSize, IVsGeneratorProgress pGenerateProgress)
        {
            if (bstrInputFileContents == null)
            {
                throw new ArgumentNullException(bstrInputFileContents);
            }
            this.codeFilePath = wszInputFilePath;
            this.codeFileNameSpace = wszDefaultNamespace;
            this.codeGeneratorProgress = pGenerateProgress;
            byte[] source = this.GenerateCode(wszInputFilePath, bstrInputFileContents);
            if (source == null)
            {
                pbstrOutputFileContents[0] = IntPtr.Zero;
                pbstrOutputFileContentSize = 0;
            }
            else
            {
                pbstrOutputFileContents[0] = Marshal.AllocCoTaskMem(source.Length);
                Marshal.Copy(source, 0, pbstrOutputFileContents[0], source.Length);
                pbstrOutputFileContentSize = (uint) source.Length;
            }
            return 0;
        }

        protected abstract byte[] GenerateCode(string inputFileName, string inputFileContent);
        protected virtual void GeneratorErrorCallback(int warning, uint level, string message, uint line, uint column)
        {
            IVsGeneratorProgress codeGeneratorProgress = this.CodeGeneratorProgress;
            if (codeGeneratorProgress != null)
            {
                NativeMethods.ThrowOnFailure(codeGeneratorProgress.GeneratorError(warning, level, message, line, column));
            }
        }

        protected byte[] StreamToBytes(Stream stream)
        {
            if (stream.Length == 0L)
            {
                return new byte[0];
            }
            long position = stream.Position;
            stream.Position = 0L;
            byte[] buffer = new byte[(int) stream.Length];
            stream.Read(buffer, 0, buffer.Length);
            stream.Position = position;
            return buffer;
        }

        internal IVsGeneratorProgress CodeGeneratorProgress
        {
            get
            {
                return this.codeGeneratorProgress;
            }
        }

        protected string FileNameSpace
        {
            get
            {
                return this.codeFileNameSpace;
            }
        }

        protected string InputFilePath
        {
            get
            {
                return this.codeFilePath;
            }
        }
    }
}

