﻿// File           : BaseResourceProvider.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections.Generic;
using System.Text;
using System.Reflection;
using System.Resources;
using System.Web.Compilation;

namespace Internationalization.Resources.Web
{
    /// <summary>
    /// BaseResourceProvider is an abstract IResourceProvider class which provides some common functionality
    /// used by resource providers
    /// </summary>
    public abstract class BaseResourceProvider : IResourceProvider
    {
        private ResourceManager resourceManager;

        /// <summary>
        /// ResourceManager is the resource manager used by the resource provider
        /// </summary>
        protected ResourceManager ResourceManager
        {
            get
            {
                if (resourceManager == null)
                    resourceManager = CreateResourceManager();

                return resourceManager;
            }
        }
        /// <summary>
        /// CreateResourceManager creates the resource manager used by the resource provider
        /// </summary>
        /// <returns>The resource manager used by the resource provider</returns>
        protected abstract ResourceManager CreateResourceManager();

        /// <summary>
        /// Gets the value of the specified Object resource for the specified culture
        /// </summary>
        /// <param name="resourceKey">The name of the resource to get</param>
        /// <param name="culture">The CultureInfo object that represents the culture for which the resource is
        /// localized</param>
        /// <returns>The value of the resource, localized for the specified culture</returns>
        public object GetObject(string resourceKey, System.Globalization.CultureInfo culture)
        {
            return ResourceManager.GetObject(resourceKey, culture);
        }
        /// <summary>
        /// ResourceReader is the IResourceReader provided by the resource provider
        /// </summary>
        public System.Resources.IResourceReader ResourceReader
        {
            get { throw new NotSupportedException(); }
        }
    }
}
