// File           : ResourceProviderUtilities.cs 
// Original Author: Guy Smith-Ferrier
// Date Created   : June 2008
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Web.Compilation;
using System.Web.Configuration;
using System.Configuration;
using Internationalization.Resources.Web;

namespace Internationalization.Web
{
    /// <summary>
    /// ResourceProviderUtilities provides utilities for handling ResourceProviderFactorys in an ASP.NET application
    /// </summary>
    public class ResourceProviderUtilities
    {
        /// <summary>
        /// GetResourceProviderFactory gets a new instance of the active ResourceProviderFactory type as set in the web.config
        /// </summary>
        /// <returns>A new instance of ResourceProviderFactory object</returns>
        /// <remarks>The Type is loaded from the resourceProviderFactoryType set in the globalization section of
        /// the web.config. If this value is not set then it defaults to ResourceManagerResourceProviderFactory.
        /// ResourceManagerResourceProviderFactory is an imitation of the ResXResourceProviderFactory.</remarks>
        public static ResourceProviderFactory GetResourceProviderFactory()
        {
            Type resourceProviderFactoryType = GetResourceProviderFactoryType();
            if (resourceProviderFactoryType == null)
                return new ResourceManagerResourceProviderFactory();
            else
                return (ResourceProviderFactory)Activator.CreateInstance(resourceProviderFactoryType);
        }
        /// <summary>
        /// GetResourceProviderFactoryType gets the "resourceProviderFactoryType" attribute value of the globalization element of web.config
        /// </summary>
        /// <returns>The "resourceProviderFactoryType" attribute value of the globalization element of web.config</returns>
        /// <remarks>GetResourceProviderFactoryType returns null if the attribute has not been set or is empty</remarks>
        public static Type GetResourceProviderFactoryType()
        {
            GlobalizationSection section = (GlobalizationSection)ConfigurationManager.GetSection("system.web/globalization");
            if (section == null)
                return null;

            if (String.IsNullOrEmpty(section.ResourceProviderFactoryType))
                return null;

            return BuildManager.GetType(section.ResourceProviderFactoryType, true, true);
        }
    }
}
