// File           : ThreadFactory.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Threading;

namespace Internationalization.Common
{
	/// <summary>
	/// ThreadFactory is a factory for creating threads
	/// </summary>
    public class ThreadFactory
    {
        /// <summary>
        /// CreateThread creates a new Thread object
        /// </summary>
        /// <param name="start">A ThreadStart delegate that represents the methods to be invoked when this thread begins executing</param>
        /// <returns>A new Thread object</returns>
        /// <remarks>The purpose of CreateThread is to provide a layer of abstraction between code which
        /// wants to create a new thread and the creation of that thread. This layer is used for ensuring
        /// that all threads are initialized appropriately. This means ensuring that the new Thread's
        /// CurrentCulture and CurrentUICulture properties are set.
        /// Use this method to replace lines like this:-
        /// Thread thread = new Thread(new ThreadStart(DoWork));
        ///</remarks>
        public static Thread CreateThread(ThreadStart start)
        {
            Thread thread = new Thread(start);
            thread.CurrentCulture   = Thread.CurrentThread.CurrentCulture;
            thread.CurrentUICulture = Thread.CurrentThread.CurrentUICulture;
            return thread;
        }
    }
}
