// File           : SocratesTranslator.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;

namespace Internationalization.Translation
{
	/// <summary>
    /// SocratesTranslator is an HTML translator for www.rustran.com
	/// </summary>
	public class SocratesTranslator: HtmlTranslator
	{
        /// <summary>
        /// Constructs a SocratesTranslator object
        /// </summary>
		public SocratesTranslator():
            base(SocratesTranslatorResources.Name, @"http://www.rustran.com/socrat.php4", new string[,]
			{
				{"en", "ru"},
				{"ru", "en"}
			})
		{
		}
        /// <summary>
        /// GetPostData gets the website-specific post data for sending to the URL
        /// </summary>
        /// <param name="inputLanguage">The language of the input text</param>
        /// <param name="outputLanguage">The language of the output text</param>
        /// <param name="text">The text to be translated</param>
        /// <returns>The post data to send to the URL</returns>
        public override string GetPostData(string inputLanguage, string outputLanguage, string text)
		{
			if (inputLanguage.Length < 2 || outputLanguage.Length < 2)
				return String.Empty;

			inputLanguage  = inputLanguage.Substring(0, 2).ToLower();
			outputLanguage = outputLanguage.Substring(0, 2).ToLower();

			string languagePair;
			if (inputLanguage == "en" && outputLanguage == "ru")
				languagePair = "3349";
			else if (inputLanguage == "ru" && outputLanguage == "en")
				languagePair = "4933";
			else
				return String.Empty;

			return "TransDir=" + languagePair +"&InBuf=" + Encode(text);
		}
        /// <summary>
        /// GetTranslation extracts the translated text from the inner text returned from the website
        /// </summary>
        /// <param name="inputLanguage">The language of the input text</param>
        /// <param name="outputLanguage">The language of the output text</param>
        /// <param name="innerText">The inner text returned from the website</param>
        /// <returns>The translated text</returns>
        /// <remarks>This is the most fragile part of an HtmlTranslator's implementation.
        /// If this translator fails check this method first. The most likely reason for
        /// failure is that the resulting HTML (and therefore inner text) has changed.</remarks>
        protected override string GetTranslation(string inputLanguage, string outputLanguage, string innerText)
		{
			int index = innerText.IndexOf("Translation:");
			if (index == -1)
				return String.Empty;

			innerText = innerText.Substring(index + 12);
			innerText = innerText.TrimStart(new char[] {' ', (char) 10, (char) 13});

			index = innerText.IndexOf("Software f");
			if (index == -1)
				return String.Empty;

			return innerText.Substring(0, index - 2).TrimEnd(new char[] {' ', (char) 10, (char) 13});
		}
	}
}
