// File           : ResearchServiceCollection.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections;

namespace Internationalization.Translation.ResearchServices
{
    /// <summary>
    /// ResearchServiceCollection is a collection of ResearchService objects
    /// </summary>
	public class ResearchServiceCollection : CollectionBase  
	{
        /// <summary>
        /// Indexer for collection
        /// </summary>
        /// <param name="index">Ordinal position of ResearchService object</param>
        /// <returns>The ResearchService object at the given index</returns>
        public ResearchService this[int index]
		{
			get  {return((ResearchService) List[index]);}
			set  {List[index] = value;}
		}
        /// <summary>
        /// Adds an ResearchService object to the collection
        /// </summary>
        /// <param name="value">The ResearchService object to add to the collection</param>
        /// <returns>The ordinal position of the added ResearchService object</returns>
        public int Add(ResearchService value)
		{
			return(List.Add(value));
		}
        /// <summary>
        /// IndexOf returns the index of the given ResearchService object
        /// </summary>
        /// <param name="value">The ResearchService object to get the index for</param>
        /// <returns>The index of the given ResearchService object</returns>
        public int IndexOf(ResearchService value)
		{
			return(List.IndexOf(value));
		}
        /// <summary>
        /// IndexOf returns the index of the given ResearchService.Name
        /// </summary>
        /// <param name="name">The ResearchService.Name to get the index for</param>
        /// <returns>The index of the given ResearchService.Name</returns>
        public int IndexOf(string name)
		{
			for(int index = 0; index < List.Count; index++)
			{
				if (((ResearchService) List[index]).Name == name)
					return index;
			}
			return -1;
		}
        /// <summary>
        /// Insert inserts an ResearchService object at the given ordinal position
        /// </summary>
        /// <param name="index">The ordinal position at which the ResearchService object should be inserted</param>
        /// <param name="value">The ResearchService object to insert</param>
        public void Insert(int index, ResearchService value)
		{
			List.Insert(index, value);
		}
        /// <summary>
        /// Remove removes an ResearchService object from the collection
        /// </summary>
        /// <param name="value">The ResearchService to remove</param>
        public void Remove(ResearchService value)
		{
			List.Remove(value);
		}
        /// <summary>
        /// Contains returns true if the collection contains the given ResearchService object
        /// </summary>
        /// <param name="value">The ResearchService object to test the collection for</param>
        /// <returns>True if the ResearchService object is in the collection</returns>
        public bool Contains(ResearchService value)
		{
			return(List.Contains(value));
		}
	}
}