// File           : ResearchServiceProviderCollection.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections;

namespace Internationalization.Translation.ResearchServices
{
    /// <summary>
    /// ResearchServiceProviderCollection is a collection of ResearchServiceProvider objects
    /// </summary>
    public class ResearchServiceProviderCollection : CollectionBase  
	{
        /// <summary>
        /// Indexer for collection
        /// </summary>
        /// <param name="index">Ordinal position of ResearchServiceProvider object</param>
        /// <returns>The ResearchServiceProvider object at the given index</returns>
        public ResearchServiceProvider this[int index]
		{
			get  {return((ResearchServiceProvider) List[index]);}
			set  {List[index] = value;}
		}
        /// <summary>
        /// Adds an ResearchServiceProvider object to the collection
        /// </summary>
        /// <param name="value">The ResearchServiceProvider object to add to the collection</param>
        /// <returns>The ordinal position of the added ResearchServiceProvider object</returns>
        public int Add(ResearchServiceProvider value)
		{
			return(List.Add(value));
		}
        /// <summary>
        /// IndexOf returns the index of the given ResearchServiceProvider object
        /// </summary>
        /// <param name="value">The ResearchServiceProvider object to get the index for</param>
        /// <returns>The index of the given ResearchServiceProvider object</returns>
        public int IndexOf(ResearchServiceProvider value)
		{
			return(List.IndexOf(value));
		}
        /// <summary>
        /// IndexOf returns the index of the given ResearchServiceProvider.Name
        /// </summary>
        /// <param name="name">The ResearchServiceProvider.Name to get the index for</param>
        /// <returns>The index of the given ResearchServiceProvider.Name</returns>
        public int IndexOf(string name)
		{
			for(int index = 0; index < List.Count; index++)
			{
				if (((ResearchServiceProvider) List[index]).Name == name)
					return index;
			}
			return -1;
		}
        /// <summary>
        /// Insert inserts an ResearchServiceProvider object at the given ordinal position
        /// </summary>
        /// <param name="index">The ordinal position at which the ResearchServiceProvider object should be inserted</param>
        /// <param name="value">The ResearchServiceProvider object to insert</param>
        public void Insert(int index, ResearchServiceProvider value)
		{
			List.Insert(index, value);
		}
        /// <summary>
        /// Remove removes an ResearchServiceProvider object from the collection
        /// </summary>
        /// <param name="value">The ResearchServiceProvider to remove</param>
        public void Remove(ResearchServiceProvider value)
		{
			List.Remove(value);
		}
        /// <summary>
        /// Contains returns true if the collection contains the given ResearchServiceProvider object
        /// </summary>
        /// <param name="value">The ResearchServiceProvider object to test the collection for</param>
        /// <returns>True if the ResearchServiceProvider object is in the collection</returns>
        public bool Contains(ResearchServiceProvider value)
		{
			return(List.Contains(value));
		}
	}
}