// File           : CloserFarTranslator.cs 
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Text;

namespace Internationalization.Translation
{
	/// <summary>
    /// CloserFarTranslator is a translator which uses a translation service called CloserFar
	/// </summary>
	public class CloserFarTranslator: Translator
	{
		private com.closerfar.www.engtoarabic engtoarabicService;

        /// <summary>
        /// Constructs a CloserFarTranslator
        /// </summary>
		public CloserFarTranslator(): base(CloserFarTranslatorResources.Name, new string[,] {{"en", "ar"}})
		{
		}
        /// <summary>
        /// Translate translates the input text from the input language to the output language
        /// </summary>
        /// <param name="inputLanguage">The language of the input text</param>
        /// <param name="outputLanguage">The language of the output text</param>
        /// <param name="text">The text to translate</param>
        /// <returns>The translated text</returns>
        public override string Translate(string inputLanguage, string outputLanguage, string text)
		{
			if (! IsSupported(inputLanguage, outputLanguage))
				throw new LanguageCombinationNotSupportedException(
                    LanguageCombinationNotSupportedResources.LanguageCombinationNotSupported,
                    inputLanguage, outputLanguage);

			if (engtoarabicService == null)
				engtoarabicService = new com.closerfar.www.engtoarabic();

			return engtoarabicService.TransLate(text);
		}
	}
}
