// File           : ITranslator.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;

namespace Internationalization.Translation
{
	/// <summary>
	/// ITranslator defines the interface for a translator
	/// </summary>
	public interface ITranslator
	{
        /// <summary>
        /// IsSupported determines if translation between a given language pair is supported
        /// </summary>
        /// <param name="inputLanguage">The language of the input string</param>
        /// <param name="outputLanguage">The language of the output string</param>
        /// <returns>True if the given language pair is supported</returns>
		bool IsSupported(string inputLanguage, string outputLanguage);
        /// <summary>
        /// Translate translates text from the input language to the output language
        /// </summary>
        /// <param name="inputLanguage">The language of the input string</param>
        /// <param name="outputLanguage">The language of the output string</param>
        /// <param name="text">The text to be translated</param>
        /// <returns>The translated string</returns>
		string Translate(string inputLanguage, string outputLanguage, string text);
        /// <summary>
        /// The name of the translation service
        /// </summary>
		string Name {get;}
        /// <summary>
        /// Enabled indicates whether the translator is enabled
        /// </summary>
		bool Enabled {get;set;}
        /// <summary>
        /// LanguagePairs is an array of language pairs
        /// </summary>
        /// <remarks>Each element of the array is an array of two elements: an input language and an output language</remarks>
		string[,] LanguagePairs {get;}
	}
}
