// File           : AddResourceStringForm.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Globalization;
using System.IO;
using System.Collections.Specialized;
using System.Text;
using Internationalization.Common;
using Internationalization.Translation;
using Internationalization.ResourceAdministration;

namespace AddResourceString
{
	/// <summary>
	/// AddResourceStringForm gets details about the new resource string to add to the resources
	/// </summary>
	public class AddResourceStringForm : System.Windows.Forms.Form
	{
		private IResourcesGovernor resourcesGovernor;
		private TranslatorCollection allTranslators;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.TextBox textBoxResourceName;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.TextBox textBoxResourceStringKey;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.TextBox textBoxResourceStringValue;
		private System.Windows.Forms.Button buttonOK;
		private System.Windows.Forms.Button buttonCancel;
		private System.Windows.Forms.CheckBox checkBoxAutomaticTranslation;
		private System.Windows.Forms.Button buttonTranslators;
		private System.Windows.Forms.Button buttonLanguages;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.TextBox textBoxInvariantLanguage;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

        /// <summary>
        /// Constructs an AddResourceStringForm object
        /// </summary>
        /// <param name="resourcesGovernor">The IResourcesGovernor of the resources</param>
        /// <param name="allTranslators">The TranslatorCollection of all translators</param>
		public AddResourceStringForm(IResourcesGovernor resourcesGovernor, TranslatorCollection allTranslators)
		{
			this.resourcesGovernor = resourcesGovernor;
			this.allTranslators = allTranslators;
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(AddResourceStringForm));
            this.label1 = new System.Windows.Forms.Label();
            this.textBoxResourceName = new System.Windows.Forms.TextBox();
            this.label2 = new System.Windows.Forms.Label();
            this.textBoxResourceStringKey = new System.Windows.Forms.TextBox();
            this.label3 = new System.Windows.Forms.Label();
            this.textBoxResourceStringValue = new System.Windows.Forms.TextBox();
            this.buttonOK = new System.Windows.Forms.Button();
            this.buttonCancel = new System.Windows.Forms.Button();
            this.checkBoxAutomaticTranslation = new System.Windows.Forms.CheckBox();
            this.buttonTranslators = new System.Windows.Forms.Button();
            this.buttonLanguages = new System.Windows.Forms.Button();
            this.label4 = new System.Windows.Forms.Label();
            this.textBoxInvariantLanguage = new System.Windows.Forms.TextBox();
            this.SuspendLayout();
            // 
            // label1
            // 
            resources.ApplyResources(this.label1, "label1");
            this.label1.Name = "label1";
            // 
            // textBoxResourceName
            // 
            resources.ApplyResources(this.textBoxResourceName, "textBoxResourceName");
            this.textBoxResourceName.Name = "textBoxResourceName";
            // 
            // label2
            // 
            resources.ApplyResources(this.label2, "label2");
            this.label2.Name = "label2";
            // 
            // textBoxResourceStringKey
            // 
            resources.ApplyResources(this.textBoxResourceStringKey, "textBoxResourceStringKey");
            this.textBoxResourceStringKey.Name = "textBoxResourceStringKey";
            // 
            // label3
            // 
            resources.ApplyResources(this.label3, "label3");
            this.label3.Name = "label3";
            // 
            // textBoxResourceStringValue
            // 
            resources.ApplyResources(this.textBoxResourceStringValue, "textBoxResourceStringValue");
            this.textBoxResourceStringValue.Name = "textBoxResourceStringValue";
            // 
            // buttonOK
            // 
            resources.ApplyResources(this.buttonOK, "buttonOK");
            this.buttonOK.Name = "buttonOK";
            this.buttonOK.Click += new System.EventHandler(this.buttonOK_Click);
            // 
            // buttonCancel
            // 
            this.buttonCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            resources.ApplyResources(this.buttonCancel, "buttonCancel");
            this.buttonCancel.Name = "buttonCancel";
            // 
            // checkBoxAutomaticTranslation
            // 
            resources.ApplyResources(this.checkBoxAutomaticTranslation, "checkBoxAutomaticTranslation");
            this.checkBoxAutomaticTranslation.Name = "checkBoxAutomaticTranslation";
            // 
            // buttonTranslators
            // 
            resources.ApplyResources(this.buttonTranslators, "buttonTranslators");
            this.buttonTranslators.Name = "buttonTranslators";
            this.buttonTranslators.Click += new System.EventHandler(this.buttonTranslators_Click);
            // 
            // buttonLanguages
            // 
            resources.ApplyResources(this.buttonLanguages, "buttonLanguages");
            this.buttonLanguages.Name = "buttonLanguages";
            this.buttonLanguages.Click += new System.EventHandler(this.buttonLanguages_Click);
            // 
            // label4
            // 
            resources.ApplyResources(this.label4, "label4");
            this.label4.Name = "label4";
            // 
            // textBoxInvariantLanguage
            // 
            resources.ApplyResources(this.textBoxInvariantLanguage, "textBoxInvariantLanguage");
            this.textBoxInvariantLanguage.Name = "textBoxInvariantLanguage";
            // 
            // AddResourceStringForm
            // 
            this.AcceptButton = this.buttonOK;
            this.CancelButton = this.buttonCancel;
            resources.ApplyResources(this, "$this");
            this.Controls.Add(this.textBoxInvariantLanguage);
            this.Controls.Add(this.label4);
            this.Controls.Add(this.buttonLanguages);
            this.Controls.Add(this.buttonTranslators);
            this.Controls.Add(this.checkBoxAutomaticTranslation);
            this.Controls.Add(this.buttonCancel);
            this.Controls.Add(this.buttonOK);
            this.Controls.Add(this.textBoxResourceStringValue);
            this.Controls.Add(this.label3);
            this.Controls.Add(this.textBoxResourceStringKey);
            this.Controls.Add(this.label2);
            this.Controls.Add(this.textBoxResourceName);
            this.Controls.Add(this.label1);
            this.Name = "AddResourceStringForm";
            this.ResumeLayout(false);
            this.PerformLayout();

		}
		#endregion

		private void buttonOK_Click(object sender, System.EventArgs e)
		{
			if (textBoxResourceName.Text.Length == 0)
				MessageBox.Show(AddResourceStringFormResources.ResourceNameMustNotBeEmpty);
			else if (textBoxResourceStringKey.Text.Length == 0)
				MessageBox.Show(AddResourceStringFormResources.ResourceStringKeyMustNotBeEmpty);
			else if (textBoxResourceStringValue.Text.Length == 0)
				MessageBox.Show(AddResourceStringFormResources.ResourceStringValueMustNotBeEmpty);
			else
			{
				string baseName = Path.GetFileNameWithoutExtension(ResourceName);
				IResourceGovernor resourceGovernor = resourcesGovernor.GetResourceGovernor(baseName, CultureInfo.InvariantCulture);
				if (! resourceGovernor.ResourceExists())
					MessageBox.Show(String.Format(AddResourceStringFormResources.ResourceDoesNotExist, ResourceName));
				else if (resourceGovernor.ResourceKeyExists(textBoxResourceStringKey.Text))
					MessageBox.Show(String.Format(AddResourceStringFormResources.ResourceKeyAlreadyExists, textBoxResourceStringKey.Text));
				else
				{
					StringCollection missingLanguages = GetMissingTargetLanguages(baseName);
					bool okToContinue = true;
					if (missingLanguages.Count > 0)
					{
						// Not all of the resources for all languages exist.
						// Tell the developer and let them decide whether to continue.
						StringBuilder message = new StringBuilder(AddResourceStringFormResources.ResourcesAreMissingForTheseLanguages 
							+ System.Environment.NewLine + System.Environment.NewLine);
						foreach(string missingLanguage in missingLanguages)
						{
							message.Append(missingLanguage + System.Environment.NewLine);
						}
						message.Append(System.Environment.NewLine + AddResourceStringFormResources.ContinueWithoutUpdatingTheseLanguages);

						okToContinue = (MessageBox.Show(message.ToString(), AddResourceStringFormResources.AddResource, MessageBoxButtons.YesNo) == DialogResult.Yes);
					}
					if (okToContinue)
						DialogResult = DialogResult.OK;
				}
			}
		}
		private StringCollection GetMissingTargetLanguages(string baseName)
		{
			StringCollection missingLanguages = new StringCollection();
			foreach(CultureInfo cultureInfo in TargetLanguages.Languages)
			{
				IResourceGovernor resourceGovernor = resourcesGovernor.GetResourceGovernor(baseName, cultureInfo);
				if (! resourceGovernor.ResourceExists())
					missingLanguages.Add(cultureInfo.DisplayName);
			}
			return missingLanguages;
		}
		private void buttonTranslators_Click(object sender, System.EventArgs e)
		{
			TranslatorsForm form = new TranslatorsForm(allTranslators);
			form.ShowDialog();
		}

		private void buttonLanguages_Click(object sender, System.EventArgs e)
		{
			LanguagesForm form = new LanguagesForm(InvariantLanguage);
			if (form.ShowDialog() == DialogResult.OK)
			{
				CultureInfo[] selectedLanguageCultureInfos = form.SelectedLanguageCultureInfos;
				string[] languageStrings = new string[selectedLanguageCultureInfos.GetLength(0)];
				int languageStringNumber = 0;
				foreach(CultureInfo cultureInfo in selectedLanguageCultureInfos)
				{
					languageStrings[languageStringNumber++] = cultureInfo.Name;
				}
				TargetLanguages.SetLanguages(languageStrings);
			}
		}
        /// <summary>
        /// ResourceName is the name of the resource (e.g. "Form1.resx")
        /// </summary>
		public string ResourceName
		{
			get {return textBoxResourceName.Text;}
			set {textBoxResourceName.Text = value;}
		}
        /// <summary>
        /// ResourceStringKey is the key of the resource string
        /// </summary>
		public string ResourceStringKey
		{
			get {return textBoxResourceStringKey.Text;}
			set {textBoxResourceStringKey.Text = value;}
		}
        /// <summary>
        /// ResourceStringValue is the invariant value of the resource string
        /// </summary>
		public string ResourceStringValue
		{
			get {return textBoxResourceStringValue.Text;}
			set {textBoxResourceStringValue.Text = value;}
		}
        /// <summary>
        /// AutomaticTranslation specifies whether to use automatic translation
        /// </summary>
		public bool AutomaticTranslation
		{
			get {return checkBoxAutomaticTranslation.Checked;}
			set {checkBoxAutomaticTranslation.Checked = value;}
		}
        /// <summary>
        /// InvariantLanguage is the ISO 639 code of the invariant (fallback) language
        /// </summary>
		public string InvariantLanguage
		{
			get {return textBoxInvariantLanguage.Text;}
			set {textBoxInvariantLanguage.Text = value;}
		}
	}
}
