// File           : ResourcesFileRef.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Text;

namespace Internationalization.ResourceAdministration
{
    /// <summary>
    /// IResourcesFileRef is an interface for managing resource file references
    /// </summary>
    public interface IResourcesFileRef
    {
        /// <summary>
        /// FileName is the name of the file in the file reference
        /// </summary>
        string FileName { get; set; }
        /// <summary>
        /// TypeName is the string of the type of data in the file
        /// </summary>
        string TypeName { get; set; }
        /// <summary>
        /// TextFileEncoding is the encoding mechanism of the file if the file is a text file
        /// </summary>
        Encoding TextFileEncoding { get; set; }
    }

    /// <summary>
    /// ResourcesFileRef manages resource file references
    /// </summary>
    public class ResourcesFileRef : IResourcesFileRef
    {
        private string fileName;
        private string typeName;
        private Encoding textFileEncoding;

        /// <summary>
        /// Constructs a ResourcesFileRef object
        /// </summary>
        /// <param name="fileName">The name of the file in the file reference</param>
        /// <param name="typeName">The string of the type of data in the file</param>
        public ResourcesFileRef(string fileName, string typeName)
        {
            this.fileName = fileName;
            this.typeName = typeName;
        }
        /// <summary>
        /// Constructs a ResourcesFileRef object
        /// </summary>
        /// <param name="fileName">The name of the file in the file reference</param>
        /// <param name="typeName">The string of the type of data in the file</param>
        /// <param name="textFileEncoding">The encoding mechanism of the file if the file is a text file</param>
        public ResourcesFileRef(string fileName, string typeName, Encoding textFileEncoding)
        {
            this.fileName = fileName;
            this.typeName = typeName;
            this.textFileEncoding = textFileEncoding;
        }
        /// <summary>
        /// FileName is the name of the file in the file reference
        /// </summary>
        public string FileName
        {
            get { return fileName; }
            set { fileName = value; }
        }
        /// <summary>
        /// TypeName is the string of the type of data in the file
        /// </summary>
        public string TypeName
        {
            get { return typeName; }
            set { typeName = value; }
        }
        /// <summary>
        /// TextFileEncoding is the encoding mechanism of the file if the file is a text file
        /// </summary>
        public Encoding TextFileEncoding
        {
            get { return textFileEncoding; }
            set { textFileEncoding = value; }
        }
    }
}
