// File           : ResourcesGovernors.cs 
// Original Author: Guy Smith-Ferrier
// Date Created   : June 2008
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections.Generic;
using System.Text;

namespace Internationalization.ResourceAdministration
{
    /// <summary>
    /// ResourcesGovernors is a class for registering IResourcesGovernors types
    /// </summary>
    public static class ResourcesGovernors
    {
        private static List<string> names = new List<string>();
        private static List<Type> types = new List<Type>();

        /// <summary>
        /// RegisterResourcesGovernorType registers an IResourcesGovernor type
        /// </summary>
        /// <param name="typeName">The simple name of the type (e.g. ResXResourcesGovernor)</param>
        /// <param name="resourcesGovernorType">The IResourcesGovernor Type to register</param>
        public static void RegisterResourcesGovernorType(string typeName, Type resourcesGovernorType)
        {
            if (names.IndexOf(typeName) == -1 && types.IndexOf(resourcesGovernorType) == -1 &&
                resourcesGovernorType != null && !String.IsNullOrEmpty(typeName))
            {
                names.Add(typeName);
                types.Add(resourcesGovernorType);
            }
        }
        /// <summary>
        /// UnregisterResourcesGovernorType unregisters an IResourcesGovernor type
        /// </summary>
        /// <param name="typeName">The IResourcesGovernor type to unregister</param>
        public static void UnregisterResourcesGovernorType(string typeName)
        {
            names.Remove(typeName);
        }
        /// <summary>
        /// UnregisterResourcesGovernorType unregisters an IResourcesGovernor type
        /// </summary>
        /// <param name="resourcesGovernorType">The IResourcesGovernor type to unregister</param>
        public static void UnregisterResourcesGovernorType(Type resourcesGovernorType)
        {
            types.Remove(resourcesGovernorType);
        }
        /// <summary>
        /// GetResourcesGovernorsTypeNames gets an array of the names of IResourcesGovernors that have been
        /// registered
        /// </summary>
        /// <returns>An array of the names of IResourcesGovernors that have been registered</returns>
        public static string[] GetResourcesGovernorsTypeNames()
        {
            return names.ToArray();
        }
        /// <summary>
        /// GetResourcesGovernorsTypes gets an array of the types of IResourcesGovernors that have been
        /// registered
        /// </summary>
        /// <returns>An array of the types of IResourcesGovernors that have been registered</returns>
        public static Type[] GetResourcesGovernorsTypes()
        {
            return types.ToArray();
        }
    }
}
