// File           : TranslatorsForm.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Globalization;
using Internationalization.Translation;

namespace Internationalization.ResourceAdministration
{
	/// <summary>
	/// TranslatorsForm allows the user to enable and disable the translators used for translation
	/// </summary>
	public class TranslatorsForm : System.Windows.Forms.Form
	{
		private TranslatorCollection translators;
		private EventHandler checkedListBoxTranslatorsSelectedIndexChangedEventHandler;

		private System.Windows.Forms.Panel panel1;
		private System.Windows.Forms.Button buttonClose;
		private System.Windows.Forms.GroupBox groupBoxTranslators;
		private System.Windows.Forms.Splitter splitter1;
		private System.Windows.Forms.GroupBox groupBoxLanguages;
		private System.Windows.Forms.CheckedListBox checkedListBoxTranslators;
		private System.Windows.Forms.ListBox listBoxLanguages;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

        /// <summary>
        /// Constructs a TranslatorsForm object
        /// </summary>
		public TranslatorsForm()
		{
			InitializeComponent();
		}
        /// <summary>
        /// Constructs a TranslatorsForm object
        /// </summary>
        /// <param name="translators">The TranslatorCollection of translators</param>
		public TranslatorsForm(TranslatorCollection translators)
		{
			checkedListBoxTranslatorsSelectedIndexChangedEventHandler = 
				new System.EventHandler(this.checkedListBoxTranslators_SelectedIndexChanged);
			InitializeComponent();
			Translators = translators;
		}
        /// <summary>
        /// Translators is the TranslatorCollection of translators
        /// </summary>
		public TranslatorCollection Translators
		{
			get {return translators;}
			set
			{
				// disable the SelectedIndexChanged event
				checkedListBoxTranslators.SelectedIndexChanged -= checkedListBoxTranslatorsSelectedIndexChangedEventHandler;
				translators = value;
				checkedListBoxTranslators.Items.Clear();
				foreach(ITranslator translator in translators)
				{
					checkedListBoxTranslators.Items.Add(translator.Name, translator.Enabled);
				}
				// enable the SelectedIndexChanged event
				checkedListBoxTranslators.SelectedIndexChanged += checkedListBoxTranslatorsSelectedIndexChangedEventHandler;
				if (translators.Count > 0)
					checkedListBoxTranslators.SelectedIndex = 0;
			}
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(TranslatorsForm));
            this.panel1 = new System.Windows.Forms.Panel();
            this.buttonClose = new System.Windows.Forms.Button();
            this.groupBoxTranslators = new System.Windows.Forms.GroupBox();
            this.checkedListBoxTranslators = new System.Windows.Forms.CheckedListBox();
            this.splitter1 = new System.Windows.Forms.Splitter();
            this.groupBoxLanguages = new System.Windows.Forms.GroupBox();
            this.listBoxLanguages = new System.Windows.Forms.ListBox();
            this.panel1.SuspendLayout();
            this.groupBoxTranslators.SuspendLayout();
            this.groupBoxLanguages.SuspendLayout();
            this.SuspendLayout();
            // 
            // panel1
            // 
            this.panel1.Controls.Add(this.buttonClose);
            resources.ApplyResources(this.panel1, "panel1");
            this.panel1.Name = "panel1";
            // 
            // buttonClose
            // 
            resources.ApplyResources(this.buttonClose, "buttonClose");
            this.buttonClose.DialogResult = System.Windows.Forms.DialogResult.OK;
            this.buttonClose.Name = "buttonClose";
            // 
            // groupBoxTranslators
            // 
            this.groupBoxTranslators.Controls.Add(this.checkedListBoxTranslators);
            resources.ApplyResources(this.groupBoxTranslators, "groupBoxTranslators");
            this.groupBoxTranslators.Name = "groupBoxTranslators";
            this.groupBoxTranslators.TabStop = false;
            // 
            // checkedListBoxTranslators
            // 
            resources.ApplyResources(this.checkedListBoxTranslators, "checkedListBoxTranslators");
            this.checkedListBoxTranslators.Name = "checkedListBoxTranslators";
            this.checkedListBoxTranslators.SelectedIndexChanged += new System.EventHandler(this.checkedListBoxTranslators_SelectedIndexChanged);
            this.checkedListBoxTranslators.ItemCheck += new System.Windows.Forms.ItemCheckEventHandler(this.checkedListBoxTranslators_ItemCheck);
            // 
            // splitter1
            // 
            resources.ApplyResources(this.splitter1, "splitter1");
            this.splitter1.Name = "splitter1";
            this.splitter1.TabStop = false;
            // 
            // groupBoxLanguages
            // 
            this.groupBoxLanguages.Controls.Add(this.listBoxLanguages);
            resources.ApplyResources(this.groupBoxLanguages, "groupBoxLanguages");
            this.groupBoxLanguages.Name = "groupBoxLanguages";
            this.groupBoxLanguages.TabStop = false;
            // 
            // listBoxLanguages
            // 
            resources.ApplyResources(this.listBoxLanguages, "listBoxLanguages");
            this.listBoxLanguages.Name = "listBoxLanguages";
            // 
            // TranslatorsForm
            // 
            resources.ApplyResources(this, "$this");
            this.Controls.Add(this.groupBoxLanguages);
            this.Controls.Add(this.splitter1);
            this.Controls.Add(this.groupBoxTranslators);
            this.Controls.Add(this.panel1);
            this.Name = "TranslatorsForm";
            this.panel1.ResumeLayout(false);
            this.groupBoxTranslators.ResumeLayout(false);
            this.groupBoxLanguages.ResumeLayout(false);
            this.ResumeLayout(false);

		}
		#endregion

		private void checkedListBoxTranslators_ItemCheck(object sender, System.Windows.Forms.ItemCheckEventArgs e)
		{
			ITranslator translator = translators[e.Index];
			translator.Enabled = (e.NewValue == CheckState.Checked);
		}

		private void checkedListBoxTranslators_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			listBoxLanguages.Items.Clear();
			ITranslator translator = translators[checkedListBoxTranslators.SelectedIndex];
			string[,] languagePairs = translator.LanguagePairs;
			if (languagePairs == null)
				listBoxLanguages.Items.Add("???");
			else
			{
				for(int pairNumber = 0; pairNumber < languagePairs.GetLength(0); pairNumber++)
				{
					string languageNames = String.Format(TranslatorsFormResources.LanguageFromTo,
						LanguageName(languagePairs[pairNumber, 0]), LanguageName(languagePairs[pairNumber, 1]));

					listBoxLanguages.Items.Add(languagePairs[pairNumber, 0] + (char) Keys.Tab + languagePairs[pairNumber, 1] +
						(char) Keys.Tab + languageNames);
				}
			}
		}
		private string LanguageName(string languageCode)
		{
			if (languageCode == "*")
				return TranslatorsFormResources.LanguageAny;

			try
			{
				CultureInfo cultureInfo = new CultureInfo(languageCode);
				return cultureInfo.DisplayName;
			}
			catch
			{
				return String.Format(TranslatorsFormResources.LanguageUnknown, languageCode);
			}
		}
	}
}
