// File           : FormLanguageMustBeDefault.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.IO;
using System.Resources;
using System.Collections;
using System.Globalization;
using Microsoft.Cci;
using Microsoft.FxCop.Sdk;
using Microsoft.FxCop.Sdk.Introspection;

namespace GlobalizationRules
{
	/// <summary>
	/// FormLanguageMustBeDefault checks that Form.Language is the default
	/// </summary>
	public class FormLanguageMustBeDefault: BaseTypeResourceRule
	{
        /// <summary>
        /// Constructs a FormLanguageMustBeDefault object
        /// </summary>
		public FormLanguageMustBeDefault(): base("FormLanguageMustBeDefault", "System.Windows.Forms.Form")
		{
		}
        /// <summary>
        /// CheckResource checks a resource for adherence to the rule
        /// </summary>
        /// <param name="type">The TypeNode to check the resource for</param>
        /// <param name="resource">The resource to check</param>
        /// <returns>The ProblemCollection of problems found by this method</returns>
        public override ProblemCollection CheckResource(TypeNode type, Resource resource)
		{
			ResourceReader reader = new ResourceReader(new System.IO.MemoryStream(resource.Data));
			try
			{
				IDictionaryEnumerator enumerator = reader.GetEnumerator();
				while (enumerator.MoveNext())
				{
					string key = (string) enumerator.Key;
					if (key == "$this.Language")
					{
						if (enumerator.Value != null && enumerator.Value is CultureInfo &&
							((CultureInfo) enumerator.Value).Equals(CultureInfo.InvariantCulture))
							return null;
						else
						{
							Resolution resolution = GetResolution(new string[] {type.Name.Name});
							Problems.Add(new Problem(resolution));
							return Problems;
						}
					}
				}
				return null;
			}
			finally
			{
				reader.Close();
			}
		}
	}
}
