// File           : DoNotUsePageCultureAttributes.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : July 2008
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections.Specialized;
using Microsoft.FxCop.Sdk;
using System.Collections.Generic;

namespace GlobalizationRulesForASPGeneratedAssemblies
{
    /// <summary>
    /// DoNotUsePageCultureAttributes checks that pages do not use Culture and UICulture attributes
    /// </summary>
    public class DoNotUsePageCultureAttributes : BaseGlobalizationRuleForASPGeneratedAssemblies
    {
        private Method checkMethod;
        /// <summary>
        /// Constructs a DoNotUsePageCultureAttributes object
        /// </summary>
        public DoNotUsePageCultureAttributes()
            : base("DoNotUsePageCultureAttributes")
        {
        }
        /// <summary>
        /// Check checks types in an assembly
        /// </summary>
        /// <param name="type">The TypeNode being checked</param>
        /// <returns>A ProblemCollection of Problems</returns>
        public override ProblemCollection Check(TypeNode type)
        {
            // We are looking for code like this:-
            //
            // private void __BuildControlTree(webformwithresourcemismatch_aspx __ctrl)
            // {
            //     __ctrl.Culture = "auto";
            //     __ctrl.UICulture = "auto";

            Identifier identifier = Identifier.For("__BuildControlTree");
            checkMethod = type.GetMethod(identifier, type);
            if (checkMethod != null)
            {
                VisitStatements(checkMethod.Body.Statements);
                return Problems;
            }
            return base.Check(type);
        }
        /// <summary>
        /// VisitMethodCall is called for each method call
        /// </summary>
        /// <param name="call">The MethodCall</param>
        public override void VisitMethodCall(MethodCall call)
        {
            if (call != null)
            {
                MemberBinding memberBinding = call.Callee as MemberBinding;
                if (memberBinding != null)
                {
                    Method method = memberBinding.BoundMember as Method;
                    if (method != null &&
                        method.DeclaringType.FullName == "System.Web.UI.Page" &&
                        (method.Name.Name == "set_Culture" || method.Name.Name == "set_UICulture") &&
                        call.Operands.Count == 1)
                    {
                        Resolution resolution = GetResolution(
                            new string[] { GetWebFormName(checkMethod.DeclaringType) });
                        Problems.Add(new Problem(resolution));
                    }
                }
            }
        }
    }
}
