using System;
using System.Collections.Generic;
using System.Text;
using GlobalizationRules;
using Microsoft.FxCop.Sdk;

namespace GlobalizationRules
{
  	/// <summary>
    /// ControlPropertiesShouldBeLocalizable checks that properties of custom controls are localizable
    /// strings
	/// </summary>
    public class ControlPropertiesShouldBeLocalizable : BaseGlobalizationRule
    {
        /// <summary>
        /// Constructs a ControlPropertiesShouldBeLocalizable object
        /// </summary>
        public ControlPropertiesShouldBeLocalizable()
            : base("ControlPropertiesShouldBeLocalizable")
        {
        }
        /// <summary>
        /// Checks all members of a type
        /// </summary>
        /// <param name="member">The Member to check</param>
        /// <returns>A collection of problems</returns>
        public override ProblemCollection Check(Member member)
        {
            PropertyNode property = member as PropertyNode;
            if (property == null)
                return null;

            if (TypeIsSubClassOf(property.DeclaringType, "System.Web.UI.WebControls.WebControl") ||
                TypeIsSubClassOf(property.DeclaringType, "System.Windows.Forms.UserControl"))
            {
                if (property.Name.Name == "Caption" ||
                    property.Name.Name == "Message" ||
                    property.Name.Name == "Text")
                {
                    // this property must be marked with the localizable attribute
                    // look through the attributes for Localizable(true)
                    bool localizableTrueAttributeFound = false;
                    foreach (AttributeNode attribute in property.Attributes)
                    {
                        if (attribute.Type.FullName == "System.ComponentModel.LocalizableAttribute")
                        {
                            // check that its value is True first
                            if (attribute.Expressions.Count > 0)
                            {
                                Literal literal = attribute.Expressions[0] as Literal;
                                if (literal != null && literal.Value is Boolean && (bool) literal.Value)
                                    localizableTrueAttributeFound = true;
                            }
                        }
                    }
                    if (!localizableTrueAttributeFound)
                    {
                        Resolution resolution = GetResolution(new string[] { property.Name.Name });
                        Problems.Add(new Problem(resolution));
                        return Problems;
                    }
                }
            }
            return base.Check(member);
        }
    }
}
