using Microsoft.Cci;
using Microsoft.Fugue;
using Microsoft.Fugue.MILA;
using Microsoft.Fugue.ProtocolManagement;
using Microsoft.Tools.FxCop.Sdk;
using Microsoft.Tools.FxCop.Sdk.Introspection;
using System;
using System.Globalization;

namespace LocalizationRules
{
    [CLSCompliant(false)]
    public sealed class DoNotPassLiteralsAsLocalizedParameters : IntrospectionGlobalizationRule
    {
        // Methods
        public DoNotPassLiteralsAsLocalizedParameters() : base("DoNotPassLiteralsAsLocalizedParameters")
        {
        }

        public override Problem[] Check(Variable destination, Variable receiver, Method caller, Method callee, ExpressionList arguments, bool isVirtualCall, IProgramContext programContext, IExecutionState prestate, IExecutionState poststate)
        {
            for (int num1 = 0; num1 < arguments.Length; num1++)
            {
                Parameter parameter1 = arguments[num1] as Parameter;
                AttributeSet set1 = programContext.AttributesOnParameter(callee, callee.Parameters[num1]);
                foreach (IAttribute attribute1 in set1)
                {
                    if (attribute1.Name == "Localized")
                    {
                        IAbstractValue value1 = prestate.Lookup((Variable) arguments[num1]);
                        IStringValue value2 = value1.StringValue(prestate);
                        if (((value2 != null) && (value2.Pattern != null)) && ((value2.Pattern.Length > 0) && (value2.Pattern[0] != null)))
                        {
                            string text1 = RuleUtilities.FormatStringWithHoles(value2);
                            string[] textArray1 = new string[3];
                            int num2 = num1 + 1;
                            textArray1[0] = num2.ToString(CultureInfo.InvariantCulture);
                            textArray1[1] = RuleUtilities.FormatMethodForDisplay(callee);
                            textArray1[2] = text1;
                            base.Problems.Add(base.GetResolution(textArray1), programContext.SourceContext.FileName, programContext.SourceContext.StartLine, text1);
                        }
                    }
                }
            }
            return base.Problems.AsArray();
        }

    }
}
