// File           : FormLocalizableMustBeTrue.cs
// Original Author: Guy Smith-Ferrier
// Date Created   : September 2005
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.IO;
using System.Resources;
using System.Collections;
using Microsoft.FxCop.Sdk;
using System.Xml;

namespace GlobalizationRules
{
    /// <summary>
    /// FormLocalizableMustBeTrue checks that Form.Localizable is true
    /// </summary>
    /// <remarks>Windows Forms 2.0 forms will not be caught by this rule.
    /// The solution is to wait until Fxcop's Resource class implements
    /// Resource.MetaData and analyze that stream as well as Resource.Data.
    /// </remarks>
    public class FormLocalizableMustBeTrue: BaseTypeResourceRule
    {
        /// <summary>
        /// Constructs a FormLocalizableMustBeTrue object
        /// </summary>
        public FormLocalizableMustBeTrue(): base("FormLocalizableMustBeTrue", "System.Windows.Forms.Form")
        {
        }
        /// <summary>
        /// CheckResource checks a resource for adherence to the rule
        /// </summary>
        /// <param name="type">The TypeNode to check the resource for</param>
        /// <param name="resource">The resource to check</param>
        /// <returns>The ProblemCollection of problems found by this method</returns>
        public override ProblemCollection CheckResource(TypeNode type, Resource resource)
		{
            ResourceReader reader = new ResourceReader(new System.IO.MemoryStream(resource.Data));
            try
            {
                IDictionaryEnumerator enumerator = reader.GetEnumerator();
                while (enumerator.MoveNext())
                {
                    string key = (string) enumerator.Key;
                    if (key == "$this.Localizable")
                    {
                        if (enumerator.Value != null && (bool) enumerator.Value)
                            return null;
                        else
                        {
                            Resolution resolution = GetResolution(new string[] {type.Name.Name});
                            Problems.Add(new Problem(resolution));
                            return Problems;
                        }
                    }
                }
                return null;
			}
			finally
			{
				reader.Close();
			}
		}
	}
}
