// File           : SetPublishStateTask.cs 
// Original Author: Guy Smith-Ferrier
// Date Created   : October 2007
// Notes          : This file is part of the downloadable source code for .NET Internationalization, by
//                  Guy Smith-Ferrier, published by Addison-Wesley. See http://www.dotneti18n.com for details.
// Disclaimer     : No warranty is provided. Use at your own risk.
// Modification   : You are free to modify this code providing that this block of comments is not altered
//                  and is placed before any code.
using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Build.Framework;
using Microsoft.Build.Utilities;
using Internationalization.ClickOnce;

namespace ClickOnceTasks
{
    /// <summary>
    /// SetPublishStateTask is an msbuild Task that sets the PublishState of ClickOnce deployed localized resources in a project file
    /// </summary>
    public class SetPublishStateTask: Task
    {
        private string projectFilename;
        private string changes;
        private bool changesMade;

        /// <summary>
        /// ProjectFilename is the name of the .csproj or .vbproj project file
        /// </summary>
        [Required]
        public string ProjectFilename
        {
            get { return projectFilename; }
            set { projectFilename = value; }
        }

        /// <summary>
        /// Changes is the comma delimited list of changes to apply to the project file
        /// </summary>
        [Required]
        public string Changes
        {
            get { return changes; }
            set { changes = value; }
        }

        /// <summary>
        /// ChangesMade is a Boolean output parameter that indicates whether changes were made to the project file
        /// </summary>
        [Output]
        public bool ChangesMade
        {
            get { return changesMade; }
            set { changesMade = value; }
        }

        /// <summary>
        /// Execute executes the build task
        /// </summary>
        /// <returns>true if successful otherwise false</returns>
        public override bool Execute()
        {
            changesMade = PublishStateHelper.SetPublishState(projectFilename, changes);
            return true;
        }
    }
}
